@@ -185,14 +185,16 @@ class Bip32Base(ABC):
         # If depth is zero, fingerprint shall be the master one and child index shall be zero
         if key_data.Depth() == 0:
             if not key_data.ParentFingerPrint().IsMasterKey():
-                raise Bip32KeyError("Invalid extended master key (wrong fingerprint)")
+                raise Bip32KeyError(
+                    f"Invalid extended master key (wrong fingerprint: {key_data.ParentFingerPrint().ToHex()})"
+                )
             if key_data.Index() != 0:
-                raise Bip32KeyError("Invalid extended master key (wrong child index)")
+                raise Bip32KeyError(f"Invalid extended master key (wrong child index: {key_data.Index().ToInt()})")
 
         # If private key, the first byte shall be zero and shall be removed
         if not is_public:
             if key_bytes[0] != 0:
-                raise Bip32KeyError("Invalid extended private key (wrong secret)")
+                raise Bip32KeyError(f"Invalid extended private key (wrong secret: {key_bytes[0]})")
             key_bytes = key_bytes[1:]
 
         return cls(priv_key=key_bytes if not is_public else None,
