@@ -22,11 +22,11 @@
 
 # Imports
 from bip_utils.addr import (
-    AlgoAddr, AtomAddr, AvaxPChainAddr, AvaxXChainAddr, EgldAddr,
-    EosAddr, EthAddr, FilSecp256k1Addr, OkexAddr, NanoAddr,
-    NeoAddr, OneAddr, P2PKHAddr, BchP2PKHAddr, SolAddr,
-    SubstrateEd25519Addr, TrxAddr, XlmAddrTypes, XlmAddr, XmrAddr,
-    XrpAddr, XtzAddrPrefixes, XtzAddr, ZilAddr
+    AlgoAddrEncoder, AtomAddrEncoder, AvaxPChainAddrEncoder, AvaxXChainAddrEncoder, BchP2PKHAddrEncoder,
+    EgldAddrEncoder, EosAddrEncoder, EthAddrEncoder, FilSecp256k1AddrEncoder, NanoAddrEncoder, NearAddrEncoder,
+    NeoAddrEncoder, OkexAddrEncoder, OneAddrEncoder, P2PKHAddrEncoder, SolAddrEncoder,
+    SubstrateEd25519AddrEncoder, TrxAddrEncoder, XlmAddrTypes, XlmAddrEncoder, XmrAddrEncoder,
+    XrpAddrEncoder, XtzAddrPrefixes, XtzAddrEncoder, ZilAddrEncoder
 )
 from bip_utils.bip.bip32 import (
     Bip32Const, Bip32KeyNetVersions, Bip32Ed25519Slip, Bip32Ed25519Blake2bSlip, Bip32Nist256p1, Bip32Secp256k1
@@ -46,6 +46,21 @@ _BIP44_BTC_KEY_NET_VER_TEST: Bip32KeyNetVersions = Bip32Const.TEST_NET_KEY_NET_V
 class Bip44Conf:
     """Class container for Bip44 configuration."""
 
+    # Configuration for Akash Network
+    AkashNetwork: BipCoinConf = BipCoinConf(
+        coin_names=CoinsConf.AkashNetwork.CoinNames(),
+        coin_idx=118,
+        is_testnet=False,
+        def_path=NOT_HARDENED_DEF_PATH,
+        key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
+        wif_net_ver=None,
+        bip32_cls=Bip32Secp256k1,
+        addr_cls=AtomAddrEncoder,
+        addr_params={
+            "hrp": CoinsConf.AkashNetwork.Params("addr_hrp"),
+        },
+    )
+
     # Configuration for Algorand
     Algorand: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Algorand.CoinNames(),
@@ -55,7 +70,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Ed25519Slip,
-        addr_cls=AlgoAddr,
+        addr_cls=AlgoAddrEncoder,
         addr_params={},
     )
 
@@ -68,7 +83,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=EthAddr,
+        addr_cls=EthAddrEncoder,
         addr_params={},
     )
     # Configuration for Avax P-Chain
@@ -80,7 +95,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=AvaxPChainAddr,
+        addr_cls=AvaxPChainAddrEncoder,
         addr_params={},
     )
     # Configuration for Avax X-Chain
@@ -92,7 +107,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=AvaxXChainAddr,
+        addr_cls=AvaxXChainAddrEncoder,
         addr_params={},
     )
 
@@ -105,7 +120,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=AtomAddr,
+        addr_cls=AtomAddrEncoder,
         addr_params={
             "hrp": CoinsConf.BandProtocol.Params("addr_hrp"),
         },
@@ -120,7 +135,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=AtomAddr,
+        addr_cls=AtomAddrEncoder,
         addr_params={
             "hrp": CoinsConf.BinanceChain.Params("addr_hrp"),
         },
@@ -134,7 +149,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=EthAddr,
+        addr_cls=EthAddrEncoder,
         addr_params={},
     )
 
@@ -147,7 +162,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=CoinsConf.BitcoinMainNet.Params("wif_net_ver"),
         bip32_cls=Bip32Secp256k1,
-        addr_cls=P2PKHAddr,
+        addr_cls=P2PKHAddrEncoder,
         addr_params={
             "net_ver": CoinsConf.BitcoinMainNet.Params("p2pkh_net_ver"),
         },
@@ -161,7 +176,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_TEST,
         wif_net_ver=CoinsConf.BitcoinTestNet.Params("wif_net_ver"),
         bip32_cls=Bip32Secp256k1,
-        addr_cls=P2PKHAddr,
+        addr_cls=P2PKHAddrEncoder,
         addr_params={
             "net_ver": CoinsConf.BitcoinTestNet.Params("p2pkh_net_ver"),
         },
@@ -176,7 +191,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=CoinsConf.BitcoinCashMainNet.Params("wif_net_ver"),
         bip32_cls=Bip32Secp256k1,
-        addr_cls=BchP2PKHAddr,
+        addr_cls=BchP2PKHAddrEncoder,
         addr_params={
             "std": {
                 "net_ver": CoinsConf.BitcoinCashMainNet.Params("p2pkh_std_net_ver"),
@@ -186,7 +201,7 @@ class Bip44Conf:
                 "net_ver": CoinsConf.BitcoinCashMainNet.Params("p2pkh_legacy_net_ver"),
             }
         },
-        addr_cls_legacy=P2PKHAddr,
+        addr_cls_legacy=P2PKHAddrEncoder,
     )
     # Configuration for Bitcoin Cash test net
     BitcoinCashTestNet: BipBitcoinCashConf = BipBitcoinCashConf(
@@ -197,7 +212,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_TEST,
         wif_net_ver=CoinsConf.BitcoinCashTestNet.Params("wif_net_ver"),
         bip32_cls=Bip32Secp256k1,
-        addr_cls=BchP2PKHAddr,
+        addr_cls=BchP2PKHAddrEncoder,
         addr_params={
             "std": {
                 "net_ver": CoinsConf.BitcoinCashTestNet.Params("p2pkh_std_net_ver"),
@@ -207,7 +222,7 @@ class Bip44Conf:
                 "net_ver": CoinsConf.BitcoinCashTestNet.Params("p2pkh_legacy_net_ver"),
             }
         },
-        addr_cls_legacy=P2PKHAddr,
+        addr_cls_legacy=P2PKHAddrEncoder,
     )
 
     # Configuration for Bitcoin Cash Simple Ledger Protocol main net
@@ -219,7 +234,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=CoinsConf.BitcoinCashSlpMainNet.Params("wif_net_ver"),
         bip32_cls=Bip32Secp256k1,
-        addr_cls=BchP2PKHAddr,
+        addr_cls=BchP2PKHAddrEncoder,
         addr_params={
             "std": {
                 "net_ver": CoinsConf.BitcoinCashSlpMainNet.Params("p2pkh_std_net_ver"),
@@ -229,7 +244,7 @@ class Bip44Conf:
                 "net_ver": CoinsConf.BitcoinCashSlpMainNet.Params("p2pkh_legacy_net_ver"),
             }
         },
-        addr_cls_legacy=P2PKHAddr,
+        addr_cls_legacy=P2PKHAddrEncoder,
     )
     # Configuration for Bitcoin Cash Simple Ledger Protocol test net
     BitcoinCashSlpTestNet: BipBitcoinCashConf = BipBitcoinCashConf(
@@ -240,7 +255,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_TEST,
         wif_net_ver=CoinsConf.BitcoinCashSlpTestNet.Params("wif_net_ver"),
         bip32_cls=Bip32Secp256k1,
-        addr_cls=BchP2PKHAddr,
+        addr_cls=BchP2PKHAddrEncoder,
         addr_params={
             "std": {
                 "net_ver": CoinsConf.BitcoinCashSlpTestNet.Params("p2pkh_std_net_ver"),
@@ -250,7 +265,7 @@ class Bip44Conf:
                 "net_ver": CoinsConf.BitcoinCashSlpTestNet.Params("p2pkh_legacy_net_ver"),
             }
         },
-        addr_cls_legacy=P2PKHAddr,
+        addr_cls_legacy=P2PKHAddrEncoder,
     )
 
     # Configuration for BitcoinSV main net
@@ -262,7 +277,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=CoinsConf.BitcoinSvMainNet.Params("wif_net_ver"),
         bip32_cls=Bip32Secp256k1,
-        addr_cls=P2PKHAddr,
+        addr_cls=P2PKHAddrEncoder,
         addr_params={
             "net_ver": CoinsConf.BitcoinSvMainNet.Params("p2pkh_net_ver"),
         },
@@ -276,7 +291,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_TEST,
         wif_net_ver=CoinsConf.BitcoinSvTestNet.Params("wif_net_ver"),
         bip32_cls=Bip32Secp256k1,
-        addr_cls=P2PKHAddr,
+        addr_cls=P2PKHAddrEncoder,
         addr_params={
             "net_ver": CoinsConf.BitcoinSvTestNet.Params("p2pkh_net_ver"),
         },
@@ -291,10 +306,40 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=EthAddr,
+        addr_cls=EthAddrEncoder,
         addr_params={},
     )
 
+    # Configuration for Certik
+    Certik: BipCoinConf = BipCoinConf(
+        coin_names=CoinsConf.Certik.CoinNames(),
+        coin_idx=118,
+        is_testnet=False,
+        def_path=NOT_HARDENED_DEF_PATH,
+        key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
+        wif_net_ver=None,
+        bip32_cls=Bip32Secp256k1,
+        addr_cls=AtomAddrEncoder,
+        addr_params={
+            "hrp": CoinsConf.Certik.Params("addr_hrp"),
+        },
+    )
+
+    # Configuration for Chihuahua
+    Chihuahua: BipCoinConf = BipCoinConf(
+        coin_names=CoinsConf.Chihuahua.CoinNames(),
+        coin_idx=118,
+        is_testnet=False,
+        def_path=NOT_HARDENED_DEF_PATH,
+        key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
+        wif_net_ver=None,
+        bip32_cls=Bip32Secp256k1,
+        addr_cls=AtomAddrEncoder,
+        addr_params={
+            "hrp": CoinsConf.Chihuahua.Params("addr_hrp"),
+        },
+    )
+
     # Configuration for Cosmos
     Cosmos: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Cosmos.CoinNames(),
@@ -304,7 +349,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=AtomAddr,
+        addr_cls=AtomAddrEncoder,
         addr_params={
             "hrp": CoinsConf.Cosmos.Params("addr_hrp"),
         },
@@ -319,7 +364,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=CoinsConf.DashMainNet.Params("wif_net_ver"),
         bip32_cls=Bip32Secp256k1,
-        addr_cls=P2PKHAddr,
+        addr_cls=P2PKHAddrEncoder,
         addr_params={
             "net_ver": CoinsConf.DashMainNet.Params("p2pkh_net_ver"),
         },
@@ -333,7 +378,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_TEST,
         wif_net_ver=CoinsConf.DashTestNet.Params("wif_net_ver"),
         bip32_cls=Bip32Secp256k1,
-        addr_cls=P2PKHAddr,
+        addr_cls=P2PKHAddrEncoder,
         addr_params={
             "net_ver": CoinsConf.DashTestNet.Params("p2pkh_net_ver"),
         },
@@ -349,7 +394,7 @@ class Bip44Conf:
                                         b"\x02\xfa\xc3\x98"),   # dgub / dgpv
         wif_net_ver=CoinsConf.DogecoinMainNet.Params("wif_net_ver"),
         bip32_cls=Bip32Secp256k1,
-        addr_cls=P2PKHAddr,
+        addr_cls=P2PKHAddrEncoder,
         addr_params={
             "net_ver": CoinsConf.DogecoinMainNet.Params("p2pkh_net_ver"),
         },
@@ -364,7 +409,7 @@ class Bip44Conf:
                                         b"\x04\x32\xa2\x43"),   # tgub / tgpv
         wif_net_ver=CoinsConf.DogecoinTestNet.Params("wif_net_ver"),
         bip32_cls=Bip32Secp256k1,
-        addr_cls=P2PKHAddr,
+        addr_cls=P2PKHAddrEncoder,
         addr_params={
             "net_ver": CoinsConf.DogecoinTestNet.Params("p2pkh_net_ver"),
         },
@@ -379,7 +424,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=CoinsConf.EcashMainNet.Params("wif_net_ver"),
         bip32_cls=Bip32Secp256k1,
-        addr_cls=BchP2PKHAddr,
+        addr_cls=BchP2PKHAddrEncoder,
         addr_params={
             "std": {
                 "net_ver": CoinsConf.EcashMainNet.Params("p2pkh_std_net_ver"),
@@ -389,7 +434,7 @@ class Bip44Conf:
                 "net_ver": CoinsConf.EcashMainNet.Params("p2pkh_legacy_net_ver"),
             }
         },
-        addr_cls_legacy=P2PKHAddr,
+        addr_cls_legacy=P2PKHAddrEncoder,
     )
     # Configuration for eCash test net
     EcashTestNet: BipBitcoinCashConf = BipBitcoinCashConf(
@@ -400,7 +445,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_TEST,
         wif_net_ver=CoinsConf.EcashTestNet.Params("wif_net_ver"),
         bip32_cls=Bip32Secp256k1,
-        addr_cls=BchP2PKHAddr,
+        addr_cls=BchP2PKHAddrEncoder,
         addr_params={
             "std": {
                 "net_ver": CoinsConf.EcashTestNet.Params("p2pkh_std_net_ver"),
@@ -410,7 +455,7 @@ class Bip44Conf:
                 "net_ver": CoinsConf.EcashTestNet.Params("p2pkh_legacy_net_ver"),
             }
         },
-        addr_cls_legacy=P2PKHAddr,
+        addr_cls_legacy=P2PKHAddrEncoder,
     )
 
     # Configuration for Elrond
@@ -422,7 +467,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Ed25519Slip,
-        addr_cls=EgldAddr,
+        addr_cls=EgldAddrEncoder,
         addr_params={},
     )
 
@@ -435,7 +480,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=EosAddr,
+        addr_cls=EosAddrEncoder,
         addr_params={},
     )
 
@@ -448,7 +493,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=EthAddr,
+        addr_cls=EthAddrEncoder,
         addr_params={},
     )
     # Configuration for Ethereum Classic
@@ -460,7 +505,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=EthAddr,
+        addr_cls=EthAddrEncoder,
         addr_params={},
     )
 
@@ -473,7 +518,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=EthAddr,
+        addr_cls=EthAddrEncoder,
         addr_params={},
     )
 
@@ -486,7 +531,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=FilSecp256k1Addr,
+        addr_cls=FilSecp256k1AddrEncoder,
         addr_params={},
     )
 
@@ -499,7 +544,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=EthAddr,
+        addr_cls=EthAddrEncoder,
         addr_params={},
     )
     # Configuration for Harmony One (Ethereum address)
@@ -511,7 +556,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=EthAddr,
+        addr_cls=EthAddrEncoder,
         addr_params={},
     )
     # Configuration for Harmony One (Atom address)
@@ -523,7 +568,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=OneAddr,
+        addr_cls=OneAddrEncoder,
         addr_params={},
     )
 
@@ -536,7 +581,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=EthAddr,
+        addr_cls=EthAddrEncoder,
         addr_params={},
     )
 
@@ -549,7 +594,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=AtomAddr,
+        addr_cls=AtomAddrEncoder,
         addr_params={
             "hrp": CoinsConf.IrisNet.Params("addr_hrp"),
         },
@@ -564,7 +609,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=AtomAddr,
+        addr_cls=AtomAddrEncoder,
         addr_params={
             "hrp": CoinsConf.Kava.Params("addr_hrp"),
         },
@@ -579,7 +624,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Ed25519Slip,
-        addr_cls=SubstrateEd25519Addr,
+        addr_cls=SubstrateEd25519AddrEncoder,
         addr_params={
             "ss58_format": CoinsConf.Kusama.Params("addr_ss58_format"),
         },
@@ -596,7 +641,7 @@ class Bip44Conf:
                                             b"\x01\x9d\x9c\xfe"),   # Ltpv / Ltub
         wif_net_ver=CoinsConf.LitecoinMainNet.Params("wif_net_ver"),
         bip32_cls=Bip32Secp256k1,
-        addr_cls=P2PKHAddr,
+        addr_cls=P2PKHAddrEncoder,
         addr_params={
             "std_net_ver": CoinsConf.LitecoinMainNet.Params("p2pkh_std_net_ver"),
             "depr_net_ver": CoinsConf.LitecoinMainNet.Params("p2pkh_depr_net_ver"),
@@ -614,7 +659,7 @@ class Bip44Conf:
                                             b"\x04\x36\xef\x7d"),   # ttub / ttpv
         wif_net_ver=CoinsConf.LitecoinTestNet.Params("wif_net_ver"),
         bip32_cls=Bip32Secp256k1,
-        addr_cls=P2PKHAddr,
+        addr_cls=P2PKHAddrEncoder,
         addr_params={
             "std_net_ver": CoinsConf.LitecoinTestNet.Params("p2pkh_std_net_ver"),
             "depr_net_ver": CoinsConf.LitecoinTestNet.Params("p2pkh_depr_net_ver"),
@@ -630,7 +675,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Ed25519Slip,
-        addr_cls=XmrAddr,
+        addr_cls=XmrAddrEncoder,
         addr_params={},
     )
 
@@ -643,7 +688,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=XmrAddr,
+        addr_cls=XmrAddrEncoder,
         addr_params={},
     )
 
@@ -656,7 +701,20 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Ed25519Blake2bSlip,
-        addr_cls=NanoAddr,
+        addr_cls=NanoAddrEncoder,
+        addr_params={},
+    )
+
+    # Configuration for Near Protocol
+    NearProtocol: BipCoinConf = BipCoinConf(
+        coin_names=CoinsConf.NearProtocol.CoinNames(),
+        coin_idx=397,
+        is_testnet=False,
+        def_path="0'",
+        key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
+        wif_net_ver=None,
+        bip32_cls=Bip32Ed25519Slip,
+        addr_cls=NearAddrEncoder,
         addr_params={},
     )
 
@@ -669,7 +727,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Nist256p1,
-        addr_cls=NeoAddr,
+        addr_cls=NeoAddrEncoder,
         addr_params={
             "ver": CoinsConf.Neo.Params("addr_ver"),
         },
@@ -684,7 +742,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=EthAddr,
+        addr_cls=EthAddrEncoder,
         addr_params={},
     )
 
@@ -697,7 +755,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=EthAddr,
+        addr_cls=EthAddrEncoder,
         addr_params={},
     )
 
@@ -710,7 +768,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=OkexAddr,
+        addr_cls=OkexAddrEncoder,
         addr_params={},
     )
 
@@ -723,7 +781,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=OkexAddr,
+        addr_cls=OkexAddrEncoder,
         addr_params={},
     )
 
@@ -736,12 +794,27 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Nist256p1,
-        addr_cls=NeoAddr,
+        addr_cls=NeoAddrEncoder,
         addr_params={
             "ver": CoinsConf.Ontology.Params("addr_ver"),
         },
     )
 
+    # Configuration for Osmosis
+    Osmosis: BipCoinConf = BipCoinConf(
+        coin_names=CoinsConf.Osmosis.CoinNames(),
+        coin_idx=118,
+        is_testnet=False,
+        def_path=NOT_HARDENED_DEF_PATH,
+        key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
+        wif_net_ver=None,
+        bip32_cls=Bip32Secp256k1,
+        addr_cls=AtomAddrEncoder,
+        addr_params={
+            "hrp": CoinsConf.Osmosis.Params("addr_hrp"),
+        },
+    )
+
     # Configuration for Polkadot (ed25519 SLIP-0010)
     PolkadotEd25519Slip: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Polkadot.CoinNames(),
@@ -751,7 +824,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Ed25519Slip,
-        addr_cls=SubstrateEd25519Addr,
+        addr_cls=SubstrateEd25519AddrEncoder,
         addr_params={
             "ss58_format": CoinsConf.Polkadot.Params("addr_ss58_format"),
         },
@@ -766,7 +839,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=EthAddr,
+        addr_cls=EthAddrEncoder,
         addr_params={},
     )
 
@@ -779,10 +852,39 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=XrpAddr,
+        addr_cls=XrpAddrEncoder,
         addr_params={},
     )
 
+    # Configuration for Secret Network (old path)
+    SecretNetworkOld: BipCoinConf = BipCoinConf(
+        coin_names=CoinsConf.SecretNetwork.CoinNames(),
+        coin_idx=118,
+        is_testnet=False,
+        def_path=NOT_HARDENED_DEF_PATH,
+        key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
+        wif_net_ver=None,
+        bip32_cls=Bip32Secp256k1,
+        addr_cls=AtomAddrEncoder,
+        addr_params={
+            "hrp": CoinsConf.SecretNetwork.Params("addr_hrp"),
+        },
+    )
+    # Configuration for Secret Network (new path)
+    SecretNetworkNew: BipCoinConf = BipCoinConf(
+        coin_names=CoinsConf.SecretNetwork.CoinNames(),
+        coin_idx=529,
+        is_testnet=False,
+        def_path=NOT_HARDENED_DEF_PATH,
+        key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
+        wif_net_ver=None,
+        bip32_cls=Bip32Secp256k1,
+        addr_cls=AtomAddrEncoder,
+        addr_params={
+            "hrp": CoinsConf.SecretNetwork.Params("addr_hrp"),
+        },
+    )
+
     # Configuration for Solana
     Solana: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.Solana.CoinNames(),
@@ -792,7 +894,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Ed25519Slip,
-        addr_cls=SolAddr,
+        addr_cls=SolAddrEncoder,
         addr_params={},
     )
 
@@ -805,7 +907,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Ed25519Slip,
-        addr_cls=XlmAddr,
+        addr_cls=XlmAddrEncoder,
         addr_params={"addr_type": XlmAddrTypes.PUB_KEY},
     )
 
@@ -818,7 +920,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=AtomAddr,
+        addr_cls=AtomAddrEncoder,
         addr_params={
             "hrp": CoinsConf.Terra.Params("addr_hrp"),
         },
@@ -833,7 +935,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Ed25519Slip,
-        addr_cls=XtzAddr,
+        addr_cls=XtzAddrEncoder,
         addr_params={"prefix": XtzAddrPrefixes.TZ1},
     )
 
@@ -846,7 +948,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=EthAddr,
+        addr_cls=EthAddrEncoder,
         addr_params={},
     )
 
@@ -859,7 +961,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=TrxAddr,
+        addr_cls=TrxAddrEncoder,
         addr_params={},
     )
 
@@ -872,10 +974,25 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=EthAddr,
+        addr_cls=EthAddrEncoder,
         addr_params={},
     )
 
+    # Configuration for Verge
+    Verge: BipCoinConf = BipCoinConf(
+        coin_names=CoinsConf.Verge.CoinNames(),
+        coin_idx=77,
+        is_testnet=False,
+        def_path=NOT_HARDENED_DEF_PATH,
+        key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
+        wif_net_ver=CoinsConf.Verge.Params("wif_net_ver"),
+        bip32_cls=Bip32Secp256k1,
+        addr_cls=P2PKHAddrEncoder,
+        addr_params={
+            "net_ver": CoinsConf.Verge.Params("p2pkh_net_ver"),
+        },
+    )
+
     # Configuration for Zcash main net
     ZcashMainNet: BipCoinConf = BipCoinConf(
         coin_names=CoinsConf.ZcashMainNet.CoinNames(),
@@ -885,7 +1002,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=CoinsConf.ZcashMainNet.Params("wif_net_ver"),
         bip32_cls=Bip32Secp256k1,
-        addr_cls=P2PKHAddr,
+        addr_cls=P2PKHAddrEncoder,
         addr_params={
             "net_ver": CoinsConf.ZcashMainNet.Params("p2pkh_net_ver"),
         },
@@ -899,7 +1016,7 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_TEST,
         wif_net_ver=CoinsConf.ZcashTestNet.Params("wif_net_ver"),
         bip32_cls=Bip32Secp256k1,
-        addr_cls=P2PKHAddr,
+        addr_cls=P2PKHAddrEncoder,
         addr_params={
             "net_ver": CoinsConf.ZcashTestNet.Params("p2pkh_net_ver"),
         },
@@ -914,6 +1031,6 @@ class Bip44Conf:
         key_net_ver=_BIP44_BTC_KEY_NET_VER_MAIN,
         wif_net_ver=None,
         bip32_cls=Bip32Secp256k1,
-        addr_cls=ZilAddr,
+        addr_cls=ZilAddrEncoder,
         addr_params={},
     )
